@@ -105,10 +105,12 @@ impl Memory {
 		value: &[u8],
 		target_size: Option<usize>
 	) -> Result<(), ExitFatal> {
-		if value.is_empty() {
-			return Ok(())
+		match target_size {
+			Some(target_size) if target_size == 0 => return Ok(()),
+			None if value.is_empty() => return Ok(()),
+			_ => (),
 		}
-		
+
 		let target_size = target_size.unwrap_or(value.len());
 
 		if offset.checked_add(target_size)
